==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication.md <==
# AmazonSimpleStorageServiceS3Replication


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')
```



| Illustration | AmazonSimpleStorageServiceS3Replication | AmazonSimpleStorageServiceS3ReplicationCard | AmazonSimpleStorageServiceS3ReplicationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication.png) | ![illustration for AmazonSimpleStorageServiceS3Replication](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ReplicationCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ReplicationCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ReplicationGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ReplicationGroup.Local.png) |




## AmazonSimpleStorageServiceS3Replication

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Replication
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3Replication('AmazonSimpleStorageServiceS3Replication', 'Amazon Simple Storage Service S3 Replication', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Replication
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3Replication('AmazonSimpleStorageServiceS3Replication', 'Amazon Simple Storage Service S3 Replication', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3ReplicationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationCard('AmazonSimpleStorageServiceS3ReplicationCard', 'Amazon Simple Storage Service S3 Replication Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationCard('AmazonSimpleStorageServiceS3ReplicationCard', 'Amazon Simple Storage Service S3 Replication Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3ReplicationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationGroup('AmazonSimpleStorageServiceS3ReplicationGroup', 'Amazon Simple Storage Service S3 Replication Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationGroup('AmazonSimpleStorageServiceS3ReplicationGroup', 'Amazon Simple Storage Service S3 Replication Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication.md <==
# AmazonSimpleStorageServiceS3Replication


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')
```



| Illustration | AmazonSimpleStorageServiceS3Replication | AmazonSimpleStorageServiceS3ReplicationCard | AmazonSimpleStorageServiceS3ReplicationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication.png) | ![illustration for AmazonSimpleStorageServiceS3Replication](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ReplicationCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ReplicationCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ReplicationGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ReplicationGroup.Local.png) |




## AmazonSimpleStorageServiceS3Replication

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Replication
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3Replication('AmazonSimpleStorageServiceS3Replication', 'Amazon Simple Storage Service S3 Replication', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Replication
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3Replication('AmazonSimpleStorageServiceS3Replication', 'Amazon Simple Storage Service S3 Replication', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3ReplicationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationCard('AmazonSimpleStorageServiceS3ReplicationCard', 'Amazon Simple Storage Service S3 Replication Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationCard('AmazonSimpleStorageServiceS3ReplicationCard', 'Amazon Simple Storage Service S3 Replication Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3ReplicationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationGroup('AmazonSimpleStorageServiceS3ReplicationGroup', 'Amazon Simple Storage Service S3 Replication Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ReplicationGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3Replication')

' renders the element
AmazonSimpleStorageServiceS3ReplicationGroup('AmazonSimpleStorageServiceS3ReplicationGroup', 'Amazon Simple Storage Service S3 Replication Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
